@@ -1,5 +1,5 @@
 package Selenium::Remote::Driver;
-$Selenium::Remote::Driver::VERSION = '0.2002';
+$Selenium::Remote::Driver::VERSION = '0.21';
 # ABSTRACT: Perl Client for Selenium Remote Driver
 
 use Moo;
@@ -228,10 +228,15 @@ sub _execute_command {
     my ( $self, $res, $params ) = @_;
     $res->{'session_id'} = $self->session_id;
     my $resource = $self->commands->get_params($res);
+
     if ($resource) {
-        my $resp =
-          $self->remote_conn->request( $resource->{'method'},
-            $resource->{'url'}, $params );
+        $params = {} unless $params;
+        my $resp = $self->remote_conn->request(
+            $resource->{method},
+            $resource->{url},
+            $resource->{no_content_success},
+            $params
+        );
         if ( ref($resp) eq 'HASH' ) {
             if ( $resp->{cmd_status} && $resp->{cmd_status} eq 'OK' ) {
                 return $resp->{cmd_return};
@@ -305,7 +310,9 @@ sub _request_new_session {
     # TODO: rewrite the testing better, this is so fragile.
     my $resp = $self->remote_conn->request(
         $self->commands->get_method('newSession'),
-        $self->commands->get_url('newSession'), $args,
+        $self->commands->get_url('newSession'),
+        $self->commands->get_no_content_success('newSession'),
+        $args,
     );
     if ( ( defined $resp->{'sessionId'} ) && $resp->{'sessionId'} ne '' ) {
         $self->session_id( $resp->{'sessionId'} );
@@ -730,10 +737,7 @@ sub set_window_position {
     my $res = { 'command' => 'setWindowPosition', 'window_handle' => $window };
     my $params = { 'x' => $x, 'y' => $y };
     my $ret = $self->_execute_command( $res, $params );
-    if ( $ret =~ m/200|204/g ) {
-        return 1;
-    }
-    else { return 0; }
+    return $ret ? 1 : 0;
 }
 
 
@@ -746,10 +750,7 @@ sub set_window_size {
     my $res = { 'command' => 'setWindowSize', 'window_handle' => $window };
     my $params = { 'height' => $height, 'width' => $width };
     my $ret = $self->_execute_command( $res, $params );
-    if ( $ret =~ m/200|204/g ) {
-        return 1;
-    }
-    else { return 0; }
+    return $ret ? 1 : 0;
 }
 
 
@@ -1106,7 +1107,7 @@ Selenium::Remote::Driver - Perl Client for Selenium Remote Driver
 
 =head1 VERSION
 
-version 0.2002
+version 0.21
 
 =head1 SYNOPSIS
 
@@ -2306,6 +2307,10 @@ Vishwanath Janmanchi <jvishwanath@gmail.com>
 
 =item *
 
+amacleay <a.macleay@gmail.com>
+
+=item *
+
 jamadam <sugama@jamadam.com>
 
 =back
