@@ -7,6 +7,7 @@ unless (-d "t" && -f "dist.ini" && -f "t/01-driver.t" && -f "t/02-webelement.t")
     die "Please run this from the root of the repo.";
 }
 
+resetEnv();
 startServer();
 
 print 'Cleaning...and building...
@@ -15,7 +16,7 @@ print `dzil clean`;
 print `dzil build`;
 
 if ($^O eq 'linux') {
-    print "Headless and need a webdriver server started? Try\n\n\tDISPLAY=:1 xvfb-run --auto-servernum java -jar /usr/lib/node_modules/protractor/selenium/selenium-server-standalone-2.40.0.jar\n\n";
+    print "Headless and need a webdriver server started? Try\n\n\tDISPLAY=:1 xvfb-run --auto-servernum java -jar /usr/lib/node_modules/protractor/selenium/selenium-server-standalone-2.42.2.jar\n\n";
 }
 
 my $srdLib = glob('Selenium-Remote-Driver*/lib');
@@ -28,7 +29,7 @@ my @files = (
 my $export = $^O eq 'MSWin32' ? 'set' : 'export';
 my $executeTests = join( ' && ', map { 'perl -I' . $srdLib . ' ' . $_ } @files);
 print `$export WD_MOCKING_RECORD=1 && $executeTests`;
-killServer();
+resetEnv();
 
 sub startServer {
     if ($^O eq 'MSWin32') {
@@ -46,3 +47,8 @@ sub killServer {
         `ps aux | grep [h]ttp-server\.pl  | awk '{print \$2}' | xargs kill`;
     }
 }
+
+sub resetEnv {
+    `dzil clean`;
+    killServer();
+}
